@@ -9,6 +9,7 @@ from .timefmt import timefmt
 from .git import git
 from .pyon2json import pyon2json
 from .csplit import csplit
+from .cpush import cpush
 
 # from .rm_timestamped import rm_timestamped
 from .obscure import obscure, unobscure
@@ -27,6 +28,7 @@ cli.add_command(timefmt)
 cli.add_command(git)
 cli.add_command(pyon2json)
 cli.add_command(csplit)
+cli.add_command(cpush)
 # cli.add_command(rm_timestamped)
 cli.add_command(obscure)
 cli.add_command(unobscure)
