@@ -1,9 +1,12 @@
 """Hello world command."""
 
+import click
 from click import secho
-from . import cli
 
-@cli.command()
+@click.command()
 def hello():
     """Print "Hello, world!"."""
     secho("Hello, world!", fg="green")
+
+if __name__ == "__main__":
+    hello()
